@@ -424,19 +424,24 @@ def get_ui_versions(s3_bucket):
         return []
 
 def s3_bucket_exists_and_not_empty(s3_bucket) -> bool:
+    logging.info(f'Checking if s3 bucket ({s3_bucket}) exists...')
     try:
         resp = s3_client.list_objects(Bucket=s3_bucket, Prefix='versions/', MaxKeys=1)
         return 'Contents' in resp
     except ClientError as e:
-        logging.warning("S3 Client error: %s" % e)
+        logging.error("S3 Client error: %s" % e)
         sys.exit(1)
 
+def s3_cp(source, target, args=''):
+    command=f'aws s3 cp {source} {target} {args}'
+    run_bash(command)
+
 def s3_sync(source, target, args=''):
     command=f'aws s3 sync {source} {target} {args}'
     run_bash(command)
 
 def s3_rm_version(s3_bucket, target, args=''):
-    command=f'aws s3 rm s3://{s3_bucket}/{target} --recursive {args}'
+    command=f'aws s3 rm s3://{s3_bucket}/versions/{target} --recursive {args}'
     run_bash(command)
 
 
@@ -704,7 +709,7 @@ def rollback_infra_cmd(stage, region, timestamp, app_dir, traits_input_file, tra
     write_traits_to_file(app, traits_output_file)
     logging.info(f'Rolling back infra ({app["name"]}) to timestamp ({app["pipeline_metadata"]["rollback"]["timestamp"]})...')
 
-    sls_rollback(stage, region, app_dir, timestamp)
+    sls_rollback(stage, region, app_dir, app["pipeline_metadata"]["rollback"]["timestamp"])
 
     app["pipeline_metadata"]["rollback"]["status"] = True
     write_traits_to_file(app, traits_output_file)
@@ -787,7 +792,7 @@ def rollback_service_cmd(stage, region, timestamp, app_dir, traits_input_file, t
     write_traits_to_file(app, traits_output_file)
     logging.info(f'Rolling back service ({app["name"]}) to timestamp ({app["pipeline_metadata"]["rollback"]["timestamp"]})...')
 
-    sls_rollback(stage, region, app_dir, timestamp)
+    sls_rollback(stage, region, app_dir, app["pipeline_metadata"]["rollback"]["timestamp"])
 
     app["pipeline_metadata"]["rollback"]["status"] = True
     write_traits_to_file(app, traits_output_file)
@@ -956,6 +961,8 @@ def deploy_ui_cmd(stage, s3_bucket, version, distribution_id, invalidate_paths,
         app["pipeline_metadata"]["deploy"]["invalidate_status"] = create_invalidation(distribution_id, invalidate_paths)
         write_traits_to_file(app, traits_output_file)
 
+    # Update the latest traits.yml file in s3
+    s3_cp(f'{traits_output_file}', f's3://{s3_bucket}/versions/{timestamp}-{version}/{traits_output_file}')
 
 
 @cli.command("rollback-ui")
